@@ -12,6 +12,7 @@
 # language governing permissions and limitations under the License.
 
 import yaml
+from awscli.compat import six
 from yaml.resolver import ScalarNode, SequenceNode
 
 
@@ -31,7 +32,7 @@ def intrinsics_multi_constructor(loader, tag_prefix, node):
 
     cfntag = prefix + tag
 
-    if tag == "GetAtt":
+    if tag == "GetAtt" and isinstance(node.value, six.string_types):
         # ShortHand notation for !GetAtt accepts Resource.Attribute format
         # while the standard notation is to use an array
         # [Resource, Attribute]. Convert shorthand to standard format
